<template>
  <div>
    <el-table :data="tableData" v-loading="loading" height="250" :border="true">
      <el-table-column
        type="index"
        width="60"
        label="序号"
        align="center"
      ></el-table-column>
      <el-table-column
        v-for="item in column[0]"
        :key="item.field"
        :prop="item.field"
        :label="item.title"
        :min-width="item.width"
        align="center"
      >
        <template #default="{ row }" v-if="item.field === 'id'">
          <el-button type="text" @click="openFormTemlpate(row)">{{
            row.id
          }}</el-button>
        </template>
        <template #default="{ row }" v-else>
          <span>{{ row[item.field] }}</span>
        </template>
      </el-table-column>
    </el-table>
    <FormTemplate
      ref="FormTemplate"
      type="detail"
      :visible.sync="formTemplateVisible"
      :templateOid="this.resembleTemplateOid"
      :codeClassifyOid="this.resembleCodeClassifyOid"
    ></FormTemplate>
  </div>
</template>

<script>
import { findLike } from "@/api/formTemplate.js";

export default {
  name: "ResembleQuery",
  props: {
    column: {
      type: Array,
      default: () => [],
    },
    codeClassifyOid: {
      type: String,
      default: "",
    },
    templateOid: {
      type: String,
      default: "",
    },
    hasResemble: {
      type: Boolean,
      default: false,
    },
    type: {
      type: String,
      default: "add",
    },
    form: {
      type: Object,
      default: () => ({}),
    },
    codeRuleOid: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      tableVisible: true,
      formTemplateVisible: false,
      activeName: "findlike",
      tableData: [],
      loading: false,
      resembleTemplateOid: "78B8C7C5-A042-0B96-FE6D-65421451782A",
      resembleCodeClassifyOid: "4524E801-6CC6-92E8-1AC3-2AB9604E8F96",
      defaultValue: {},
      secVOList: [],
      defaultKeys: [
        "oid",
        "id",
        "name",
        "description",
        "revisionoid",
        "nameoid",
        "btmname",
        "lastr",
        "firstr",
        "lastv",
        "firstv",
        "creator",
        "createtime",
        "lastModifier",
        "lastmodifytime",
        "revisionrule",
        "revisionseq",
        "revisionvalue",
        "versionrule",
        "versionseq",
        "versionvalue",
        "lcstatus",
        "ts",
        "owner",
        "checkinby",
        "checkintime",
        "checkoutby",
        "checkouttime",
        "copyfromversion",
        "secretgrade",
      ],
      formItems: [],
    };
  },
  created() {
    this.getCodeRule();
  },
  computed: {
    showCodeOrder() {
      if (this.type === "add") {
        if (this.secVOList.length == 0 && this.hasResemble) {
          return false;
        }
      } else {
        if (this.hasResemble) {
          return false;
        }
      }
      return true;
    },
  },
  methods: {
    // 相似项查询
    resembleQuery(form) {
      this.loading = true;
      this.activeName = "findlike";
      const { defaultValue, formValue } = this.getDefaultValueAndFormValues(form);
      let params = {
        codeClassifyOid: this.codeClassifyOid,
        codeRuleOid: this.codeRuleOid,
        templateOid: this.templateOid,
        data: formValue,
      };
      params = Object.assign(params, defaultValue);
      this.tableVisible = true;
      findLike(params).then((res) => {
        this.loading = false;
        this.tableData = res.data.data || [];
      });
    },
    
    openFormTemlpate(row) {
      this.$nextTick(() => {
        console.log(this.$refs.FormTemplate);
      });
      this.codetemplateoid = row.codetemplateoid;
      this.formTemplateVisible = true;
    },
    getDefaultValueAndFormValues(form) {
      let defaultValue = {};
      let formValue = {};
      for (const key in form) {
        if (Object.hasOwnProperty.call(form, key)) {
          const element = form[key];
          if (this.defaultKeys.includes(key)) {
            defaultValue[key] = element;
          } else {
            formValue[key] = element;
          }
        }
      }
      return {
        defaultValue,
        formValue,
      };
    },
  },
  
};
</script>